@@ -1,5 +1,13 @@
+package Exception::Routing;
+$Exception::Routing::VERSION = '0.006';
+use base qw(Exception);
+
+package Exception::Routing::CSRF;
+$Exception::Routing::CSRF::VERSION = '0.006';
+use base qw(Exception::Routing);
+
 package QBit::WebInterface::Routing;
-$QBit::WebInterface::Routing::VERSION = '0.005';
+$QBit::WebInterface::Routing::VERSION = '0.006';
 use POSIX qw(strftime setlocale LC_TIME);
 
 use qbit;
@@ -9,8 +17,6 @@ use QBit::WebInterface::Response;
 
 use base qw(QBit::WebInterface QBit::Application);
 
-eval {require Exception::WebInterface::Controller::CSRF; require Exception::Request::UnknownMethod};
-
 sub import {
     my ($package, %opts) = @_;
 
@@ -108,7 +114,7 @@ sub build_response {
         $cmd = $cmds->{$path}{'__DEFAULT__'}{'name'} if $cmd eq '';
         $cmd = '' unless defined($cmd);
     }
-    
+
     $self->set_option(cur_cmd     => $cmd);
     $self->set_option(cur_cmdpath => $path);
 
@@ -133,7 +139,7 @@ sub build_response {
 
                 unless ($controller->{'__BREAK_CMD__'}) {
                     if ($controller->attrs()->{'SAFE'}) {
-                        throw Exception::WebInterface::Controller::CSRF gettext('CSRF has been detected')
+                        throw Exception::Routing::CSRF gettext('CSRF has been detected')
                           unless $controller->check_anti_csrf_token(
                             $self->request->param(sign => $params{'sign'} // ''),
                             url => $self->get_option('cur_cmdpath') . '/' . $self->get_option('cur_cmd'));
